﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using System.Linq;
using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.DataAnalysis {
  [Item("Constant Classification Model", "A model that always returns the same constant value regardless of the presented input data.")]
  public class ConstantClassificationModel : NamedItem, IClassificationModel {
    [Storable]
    protected double constant;
    public double Constant {
      get { return constant; }
    }

    [StorableConstructor]
    protected ConstantClassificationModel(bool deserializing) : base(deserializing) { }
    protected ConstantClassificationModel(ConstantClassificationModel original, Cloner cloner)
      : base(original, cloner) {
      this.constant = original.constant;
    }
    public override IDeepCloneable Clone(Cloner cloner) { return new ConstantClassificationModel(this, cloner); }

    public ConstantClassificationModel(double constant)
      : base() {
      this.name = ItemName;
      this.description = ItemDescription;
      this.constant = constant;
    }

    public IEnumerable<double> GetEstimatedClassValues(Dataset dataset, IEnumerable<int> rows) {
      return rows.Select(row => Constant);
    }

    public IClassificationSolution CreateClassificationSolution(IClassificationProblemData problemData) {
      return new ConstantClassificationSolution(this, new ClassificationProblemData(problemData));
    }
  }
}
